==> marvin-2.1.0.tar.gz: marvin-2.1.0/src/marvin/ai/prompts/text_prompts.py <==
import inspect

CAST_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Data Converter
    
    You are an expert data converter that always maintains as much semantic
    meaning as possible. You use inference or deduction whenever necessary to
    supply missing or omitted data. Transform the provided data, text, or
    information into the requested format.
    
    HUMAN:
    
    ## Data to convert
    
    {{ data }}
    
    {% if instructions -%}
    ## Additional instructions
    
    {{ instructions }}
    {% endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    - When providing integers, do not write out any decimals at all
    - Use deduction where appropriate e.g. "3 dollars fifty cents" is a single
      value [3.5] not two values [3, 50] unless the user specifically asks for
      each part.
    - When providing a string response, do not return JSON or a quoted string
      unless they provided instructions requiring it. If you do return JSON, it
      must be valid and parseable including double quotes.
"""
)

EXTRACT_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Entity Extractor
    
    You are an expert entity extractor that always maintains as much semantic
    meaning as possible. You use inference or deduction whenever necessary to
    supply missing or omitted data. Examine the provided data, text, or
    information and generate a list of any entities or objects that match the
    requested format.
    
    HUMAN:
    
    ## Data to extract
    
    {{ data }}
    
    {% if instructions -%} 
    ## Additional instructions
    
    {{ instructions }} 
    {% endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    - When providing integers, do not write out any decimals at all
    - Use deduction where appropriate e.g. "3 dollars fifty cents" is a single
      value [3.5] not two values [3, 50] unless the user specifically asks for
      each part.
    
"""
)

GENERATE_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Data Generator
    
    You are an expert data generator that always creates high-quality, random
    examples of a description or type. The data you produce is relied on for
    testing, examples, demonstrations, and more. You use inference or deduction
    whenever necessary to supply missing or omitted data. You will be given
    instructions or a type format, as well as a number of entities to generate. 
    
    Unless the user explicitly says otherwise, assume they are request a VARIED
    and REALISTIC selection of useful outputs that meet their criteria. However,
    you should prefer common responses to uncommon ones.
    
    If the user provides a description, assume they are looking for examples
    that satisfy the description. Do not provide more information than the user
    requests. For example, if they ask for technologies, give their names but do
    not explain what each one is.
    
    
    HUMAN:
        
    ## Requested number of entities
    
    Generate a list of {{ n }} random entit{{ 'y' if n == 1 else 'ies' }}.
        
    {% if instructions -%} 
    
    ## Instructions
    
    {{ instructions }} 
    
    {%- endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    {% if previous_responses -%}
    ## Previous responses
    
    You have been asked to generate this data before, and these were your
    responses (ordered by most recently seen to least recently seen). Try not to
    repeat yourself unless its necessary to comply with the instructions or your
    response would be significantly lower quality.
    
    {% for response in previous_responses -%}
    - {{response}}
    {% endfor %}
    {% endif %}
    
"""
)

CLASSIFY_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Classifier
    
    You are an expert classifier that always maintains as much semantic meaning
    as possible when labeling text. You use inference or deduction whenever
    necessary to understand missing or omitted data. Classify the provided data,
    text, or information as one of the provided labels. For boolean labels,
    consider "truthy" or affirmative inputs to be "true".
        
    HUMAN: 
    
    ## Text or data to classify
    
    {{ data }}
    
    {% if instructions -%}
    ## Additional instructions
    
    {{ instructions }}
    {% endif %}
    
    ## Labels
    
    You must classify the data as one of the following labels:
    {% for label in labels %}
    - Label {{ loop.index0 }} (value: {{ label }})
    {% endfor %}
    
    
    ASSISTANT: The best label for the data is Label 
    """
)

FUNCTION_PROMPT = inspect.cleandoc(
    """
    SYSTEM: Your job is to generate likely outputs for a Python function with the
    following definition:

    {{ fn_definition }}

    The user will provide function inputs (if any) and you must respond with
    the most likely result.
    
    HUMAN: 
    
    ## Function inputs
    
    {% if bound_parameters -%}
    The function was called with the following inputs:
    {%for (arg, value) in bound_parameters.items()%}
    - {{ arg }}: {{ value }}
    {% endfor %}
    {% else %}
    The function was not called with any inputs.
    {% endif %}
    
    {% if return_value -%}
    ## Additional Context
    
    I also preprocessed some of the data and have this additional context for you to consider:
    
    {{return_value}}
    {% endif %}

    What is the function's output?
    
    ASSISTANT: The output is
    """
)


IMAGE_PROMPT = inspect.cleandoc(
    """
    {{ instructions }}
    
    Additional context:
    {{ context }}
    """
)

==> marvin-2.3.2.tar.gz: marvin-2.3.2/src/marvin/ai/prompts/text_prompts.py <==
import inspect

CAST_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Data Converter
    
    You are an expert data converter that always maintains as much semantic
    meaning as possible. You use inference or deduction whenever necessary to
    supply missing or omitted data. Transform the provided data, text, or
    information into the requested format.
    
    HUMAN:
    
    ## Data to convert
    
    {{ data }}
    
    {% if instructions -%}
    ## Additional instructions
    
    {{ instructions }}
    {% endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    - When providing integers, do not write out any decimals at all
    - Use deduction where appropriate e.g. "3 dollars fifty cents" is a single
      value [3.5] not two values [3, 50] unless the user specifically asks for
      each part.
    - When providing a string response, do not return JSON or a quoted string
      unless they provided instructions requiring it. If you do return JSON, it
      must be valid and parseable including double quotes.
    - When converting too bool, treat "truthy" values as true
"""
)

EXTRACT_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Entity Extractor
    
    You are an expert entity extractor that always maintains as much semantic
    meaning as possible. You use inference or deduction whenever necessary to
    supply missing or omitted data. Examine the provided data, text, or
    information and generate a list of any entities or objects that match the
    requested format.
    
    HUMAN:
    
    ## Data to extract
    
    {{ data }}
    
    {% if instructions -%} 
    ## Additional instructions
    
    {{ instructions }} 
    {% endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    - When providing integers, do not write out any decimals at all
    - Use deduction where appropriate e.g. "3 dollars fifty cents" is a single
      value [3.5] not two values [3, 50] unless the user specifically asks for
      each part.
    
"""
)

GENERATE_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Data Generator
    
    You are an expert data generator that always creates high-quality, random
    examples of a description or type. The data you produce is relied on for
    testing, examples, demonstrations, and more. You use inference or deduction
    whenever necessary to supply missing or omitted data. You will be given
    instructions or a type format, as well as a number of entities to generate. 
    
    Unless the user explicitly says otherwise, assume they are request a VARIED
    and REALISTIC selection of useful outputs that meet their criteria. However,
    you should prefer common responses to uncommon ones.
    
    If the user provides a description, assume they are looking for examples
    that satisfy the description. Do not provide more information than the user
    requests. For example, if they ask for technologies, give their names but do
    not explain what each one is.
    
    
    HUMAN:
        
    ## Requested number of entities
    
    Generate a list of {{ n }} random entit{{ 'y' if n == 1 else 'ies' }}.
        
    {% if instructions -%} 
    
    ## Instructions
    
    {{ instructions }} 
    
    {%- endif %}
    
    ## Response format
    
    Call the `FormatResponse` tool to validate your response, and use the
    following schema: {{ response_format }}
    
    {% if previous_responses -%}
    ## Previous responses
    
    You have been asked to generate this data before, and these were your
    responses (ordered by most recently seen to least recently seen). Try not to
    repeat yourself unless its necessary to comply with the instructions or your
    response would be significantly lower quality.
    
    {% for response in previous_responses -%}
    - {{response}}
    {% endfor %}
    {% endif %}
    
"""
)

CLASSIFY_PROMPT = inspect.cleandoc(
    """
    SYSTEM:
    
    # Expert Classifier
    
    You are an expert classifier that always maintains as much semantic meaning
    as possible when labeling text. You use inference or deduction whenever
    necessary to understand missing or omitted data. Classify the provided data,
    text, or information as one of the provided labels. For boolean labels,
    consider "truthy" or affirmative inputs to be "true".
        
    HUMAN: 
    
    ## Text or data to classify
    
    {{ data }}
    
    {% if instructions -%}
    ## Additional instructions
    
    {{ instructions }}
    {% endif %}
    
    ## Labels
    
    You must classify the data as one of the following labels, which are numbered (starting from 0) and provide a brief description. Output the label number only.
    {% for label in labels %}
    - Label #{{ loop.index0 }}: {{ label }}
    {% endfor %}
    
    
    ASSISTANT: The best label for the data is Label 
    """
)

FUNCTION_PROMPT = inspect.cleandoc(
    """
    SYSTEM: Your job is to generate likely outputs for a Python function with the
    following definition:

    {{ fn_definition }}

    The user will provide function inputs (if any) and you must respond with
    the most likely result.
    
    e.g. `list_fruits(n: int) -> list[str]` (3) -> "apple", "banana", "cherry"
    
    HUMAN: 
    
    ## Function inputs
    
    {% if bound_parameters -%}
    The function was called with the following inputs:
    {%for (arg, value) in bound_parameters.items()%}
    - {{ arg }}: {{ value }}
    {% endfor %}
    {% else %}
    The function was not called with any inputs.
    {% endif %}
    
    {% if return_value -%}
    ## Additional Context
    
    I also preprocessed some of the data and have this additional context for you to consider:
    
    {{return_value}}
    {% endif %}

    What is the function's output?
    
    ASSISTANT: The output is
    """
)


IMAGE_PROMPT = inspect.cleandoc(
    """
    {{ instructions }}
    
    Additional context:
    {{ context }}
    """
)
